@@ -8,7 +8,7 @@
 --                (c) Jeremy Shaw 2005
 -- License     :  BSD-style
 --
--- Maintainer  :  bjorn@bringert.net
+-- Maintainer  :  Anders Kaseorg <andersk@mit.edu>
 -- Stability   :  experimental
 -- Portability :  non-portable (uses Control.Monad.State)
 --
@@ -94,7 +94,7 @@ module Network.CGI (
   , module Network.CGI.Compat
   ) where
 
-import Control.Exception (Exception(..), SomeException, ErrorCall(..))
+import Control.Exception.Extensible (Exception(..), SomeException, ErrorCall(..))
 import Control.Monad (liftM)
 import Control.Monad.Trans (MonadIO, liftIO)
 import Data.Char (toUpper)
@@ -104,7 +104,6 @@ import qualified Data.Map as Map
 import Network.URI (URI(..), URIAuth(..), nullURI, parseRelativeReference, 
                     escapeURIString, isUnescapedInURI)
 import System.IO (stdin, stdout)
-import System.IO.Error (isUserError, ioeGetErrorString)
 
 import qualified Data.ByteString.Lazy.Char8 as BS
 import Data.ByteString.Lazy.Char8 (ByteString)
@@ -117,7 +116,7 @@ import Network.CGI.Monad
 import Network.CGI.Protocol
 import Network.CGI.Compat
 
-import Text.XHtml (Html, renderHtml, header, (<<), thetitle, (+++), 
+import Text.XHtml (renderHtml, header, (<<), thetitle, (+++), 
                    body, h1, paragraph, hr, address)
 
 
@@ -186,8 +185,9 @@ handleErrors = flip catchCGI outputException
 --   an 'Exception'.
 outputException :: (MonadCGI m,MonadIO m) => SomeException -> m CGIResult
 outputException e = outputInternalServerError es
-    where es | Just (ErrorCall msg) <- fromException e = [msg]
-             | otherwise                               = [show e]
+    where es = case fromException e of
+                 Just (ErrorCall msg) -> [msg]
+                 _ -> [show e]
 
 -- | Output an error page to the user, with the given
 --   HTTP status code in the response. Also logs the error information
